<?php
/*
Plugin Name: Facebook Recommend Widget
Plugin URI: http://glauserconsulting.com/en/other/
Author URI: http://glauserconsulting.com
Description: Widget that displays a Facebook Recommend Button for your site.
Author: Ivan Glauser
Version: 1.1.2
*/


/**
 * Facebook_Recommend Class
 */
class Facebook_Recommend extends WP_Widget {
    /** constructor */
    function Facebook_Recommend() {
        parent::WP_Widget(false, $name = 'Facebook Recommend', array('description' => 'Widget that displays a Facebook Recommend Button.', 'class' => 'facebook-recommend'));	
    }

    /** @see WP_Widget::widget */
    function widget($args, $instance) {		
        extract( $args );
        $url_to_like = apply_filters('widget_title', $instance['url_to_like']);
        $layout_style = $instance['layout_style'];
		$show_faces = empty($instance['show_faces']) ? 'false' : 'true';
		$width = apply_filters('widget_title', $instance['width']);
		$verb_to_display = $instance['verb_to_display'];
		$color_scheme = $instance['color_scheme'];
        ?>  <!-- Add localinformation e.g. src="http://www.facebook.com/widgets/like.php?locale=fr_FR&..."
 -->
            <?php echo $before_widget; ?>
				<li class="widget facebook-recommend"><div class="textwidget">
					<iframe src="http://www.facebook.com/plugins/like.php?href=<?php echo $url_to_like; ?>&amp;layout=<?php echo $layout_style; ?>&amp;show_faces=<?php echo $show_faces; ?>&amp;width=<?php echo $width; ?>&amp;action=<?php echo $verb_to_display; ?>&amp;colorscheme=<?php echo $color_scheme; ?>&amp;locale=<?php echo get_locale(); ?>" scrolling="no" frameborder="0" width=<?php echo $width; ?>></iframe>
				</div></li>
            <?php echo $after_widget; ?>
        <?php
    }

    /** @see WP_Widget::update */
    function update($new_instance, $old_instance) {				
		$instance = $old_instance;
		$instance['url_to_like'] = strip_tags($new_instance['url_to_like']);
		$instance['layout_style'] = $new_instance['layout_style'];
		$instance['show_faces'] = $new_instance['show_faces'];
		$instance['width'] = strip_tags($new_instance['width']);
		$instance['verb_to_display'] = $new_instance['verb_to_display'];
		$instance['color_scheme'] = $new_instance['color_scheme'];
        return $instance;
    }

    /** @see WP_Widget::form */
    function form($instance) {
		$instance = wp_parse_args( (array) $instance, array( 'url_to_like' => $_SERVER['SERVER_NAME'], 'layout_style' => '', 'show_faces' => true, 'width' => '200', 'verb_to_display' => 'recommend', 'color_scheme' => 'light' ) );
		
        $url_to_like = esc_attr($instance['url_to_like']);
		$layout_style = $instance['layout_style'];
		$show_faces = $instance['show_faces'];
		$width = esc_attr($instance['width']);
		$verb_to_display = $instance['verb_to_display'];
		$color_scheme = $instance['color_scheme'];
        ?>
            <p>
				<label for="<?php echo $this->get_field_id('url_to_like'); ?>"><?php _e('URL to Like: '); ?><label title="The URL to like/recommend.">(?)</label><input class="widefat" id="<?php echo $this->get_field_id('url_to_like'); ?>" name="<?php echo $this->get_field_name('url_to_like'); ?>" type="text" value="<?php echo $url_to_like; ?>" /></label>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('layout_style'); ?>"><?php _e('Layout Style: '); ?><select class="widefat" id="<?php echo $this->get_field_id('layout_style'); ?>" name="<?php echo $this->get_field_name('layout_style'); ?>">
				<option value="standard" <?php echo ($layout_style=='standard')?'selected':''; ?>>Standard</option>
				<option value="button_count" <?php echo ($layout_style=='button_count')?'selected':''; ?>>Button Count</option>
				<option value="box_count" <?php echo ($layout_style=='box_count')?'selected':''; ?>>Box Count</option>
			</select></label>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('show_faces'); ?>"><?php _e('Show Faces: ', 'fbrecommend'); ?><input type="checkbox" id="<?php echo $this->get_field_id('show_faces'); ?>" name="<?php echo $this->get_field_name('show_faces'); ?>" <?php echo ($show_faces=='on')?'checked="checked"':''; ?>/></label>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('width'); ?>"><?php _e('Width (pixels): '); ?><input class="widefat" id="<?php echo $this->get_field_id('width'); ?>" name="<?php echo $this->get_field_name('width'); ?>" type="text" value="<?php echo $width; ?>" /></label>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('verb_to_display'); ?>"><?php _e('Verb to Display: '); ?><select class="widefat" id="<?php echo $this->get_field_id('verb_to_display'); ?>" name="<?php echo $this->get_field_name('verb_to_display'); ?>">
				<option value="like" <?php echo ($verb_to_display=='like')?'selected':''; ?>>Like</option>
				<option value="recommend" <?php echo ($verb_to_display=='recommend')?'selected':''; ?>>Recommend</option>
				</select></label>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('color_scheme'); ?>"><?php _e('Color Scheme: '); ?><select class="widefat" id="<?php echo $this->get_field_id('color_scheme'); ?>" name="<?php echo $this->get_field_name('color_scheme'); ?>">
				<option value="light" <?php echo ($color_scheme=='light')?'selected':''; ?>>Light</option>
				<option value="dark" <?php echo ($color_scheme=='dark')?'selected':''; ?>>Dark</option>
				</select></label>
			</p>
        <?php 
    }

} // class Facebook_Recommend

// register Facebook_Recommend widget
add_action('widgets_init', create_function('', 'return register_widget("Facebook_Recommend");'));

add_action('wp_head', 'add_open_graph_meat_tags');



function add_open_graph_meat_tags()
{
	if (strlen(get_option('open_graph_title')) > 0
		&& strlen(get_option('open_graph_type')) > 0
		&& strlen(get_option('open_graph_image')) > 0
		&& strlen(get_option('open_graph_url')) > 0) {
		echo '<meta property="og:title" content="'.get_option('open_graph_title').'">';
		echo '<meta property="og:type" content="'.get_option('open_graph_type').'">';
		echo '<meta property="og:image" content="'.get_option('open_graph_image').'">';
		echo '<meta property="og:url" content="'.get_option('open_graph_url').'">';
		if(strlen(get_option('open_graph_site_name')) > 0) {
			echo '<meta property="og:site_name" content="'.get_option('open_graph_site_name').'">';
		}
		if(strlen(get_option('open_graph_admins')) > 0) {
			echo '<meta property="fb:admins" content="'.get_option('open_graph_admins').'">';
		}
		if(strlen(get_option('open_graph_description')) > 0) {
			echo '<meta property="og:description" content="'.get_option('open_graph_description').'">';
		}
	}
}


// create custom plugin settings menu
add_action('admin_menu', 'facebook_recommend_create_menu');

function facebook_recommend_create_menu() {

	//create new top-level menu
	add_menu_page('Facebook Recommend Settings', 'FB Recommend', 'administrator', __FILE__, 'facebook_recommend_settings_page',plugins_url('/images/facebook-recommend.png', __FILE__));

	//call register settings function
	add_action( 'admin_init', 'register_facebook_recommend_settings' );
}


function register_facebook_recommend_settings() {
	//register our settings
	register_setting('facebook-recommend-settings-group', 'open_graph_title');
	register_setting('facebook-recommend-settings-group', 'open_graph_type');
	register_setting('facebook-recommend-settings-group', 'open_graph_image');
	register_setting('facebook-recommend-settings-group', 'open_graph_url');
	register_setting('facebook-recommend-settings-group', 'open_graph_site_name');
	register_setting('facebook-recommend-settings-group', 'open_graph_admins');
	register_setting('facebook-recommend-settings-group', 'open_graph_description');
}

function facebook_recommend_settings_page() {
?>
<div class="wrap">
<h2>Facebook Recommend - Open Graph Settings</h2>

<form method="post" action="options.php">
    <?php settings_fields( 'facebook-recommend-settings-group' ); ?>
	Open Graph tags are <meta> tags that you add to the <head> of your website to describe the entity your page represents, whether it is a band, restaurant, blog, or something else. Read more about it <a href="http://developers.facebook.com/docs/opengraph">here</a>.
    <table class="form-table">
        <tr valign="top">
        <th scope="row">Title: *</th>
        <td><input type="text" name="open_graph_title" value="<?php echo get_option('open_graph_title'); ?>" /><span class="description"> The title of your object as it should appear within the graph.</span></td>
        </tr>
		
		<tr valign="top">
        <th scope="row">Type: *</th>
        <td><select class="postform" type="text" name="open_graph_type" value="<?php echo get_option('open_graph_type'); ?>">
			<option value="">- Select -</option>
			<option disabled="true">ACTIVITIES</option>
			<option value="activity" <?php echo (get_option('open_graph_type')=='activity')?'selected':''; ?>>- Activity</option>
			<option value="sport" <?php echo (get_option('open_graph_type')=='sport')?'selected':''; ?>>- Sport</option>
			<option disabled="true">BUSINESSES</option>
			<option value="bar" <?php echo (get_option('open_graph_type')=='bar')?'selected':''; ?>>- Bar</option>
			<option value="company" <?php echo (get_option('open_graph_type')=='company')?'selected':''; ?>>- Company</option>
			<option value="cafe" <?php echo (get_option('open_graph_type')=='cafe')?'selected':''; ?>>- Cafe</option>
			<option value="hotel" <?php echo (get_option('open_graph_type')=='hotel')?'selected':''; ?>>- Hotel</option>
			<option value="restaurant" <?php echo (get_option('open_graph_type')=='restaurant')?'selected':''; ?>>- Restaurant</option>
			<option disabled="true">GROUPS</option>
			<option value="cause" <?php echo (get_option('open_graph_type')=='cause')?'selected':''; ?>>- Cause</option>
			<option value="sports_league" <?php echo (get_option('open_graph_type')=='sports_league')?'selected':''; ?>>- Sports League</option>
			<option value="sports_team" <?php echo (get_option('open_graph_type')=='sports_team')?'selected':''; ?>>- Sports Team</option>
			<option disabled="true">ORGANIZATIONS</option>
			<option value="band" <?php echo (get_option('open_graph_type')=='band')?'selected':''; ?>>- Band</option>
			<option value="government" <?php echo (get_option('open_graph_type')=='government')?'selected':''; ?>>- Government</option>
			<option value="non_profit" <?php echo (get_option('open_graph_type')=='non_profit')?'selected':''; ?>>- Non Profit</option>
			<option value="school" <?php echo (get_option('open_graph_type')=='school')?'selected':''; ?>>- School</option>
			<option value="university" <?php echo (get_option('open_graph_type')=='university')?'selected':''; ?>>- University</option>
			<option disabled="true">PEOPLE</option>
			<option value="actor" <?php echo (get_option('open_graph_type')=='actor')?'selected':''; ?>>- Actor</option>
			<option value="athlete" <?php echo (get_option('open_graph_type')=='athlete')?'selected':''; ?>>- Athlete</option>
			<option value="author" <?php echo (get_option('open_graph_type')=='author')?'selected':''; ?>>- Author</option>
			<option value="director" <?php echo (get_option('open_graph_type')=='director')?'selected':''; ?>>- Director</option>
			<option value="musician" <?php echo (get_option('open_graph_type')=='musician')?'selected':''; ?>>- Musician</option>
			<option value="politician" <?php echo (get_option('open_graph_type')=='politician')?'selected':''; ?>>- Politician</option>
			<option value="public_figure" <?php echo (get_option('open_graph_type')=='public_figure')?'selected':''; ?>>- Public Figure</option>
			<option disabled="true">PLACES</option>
			<option value="city" <?php echo (get_option('open_graph_type')=='city')?'selected':''; ?>>- City</option>
			<option value="country" <?php echo (get_option('open_graph_type')=='country')?'selected':''; ?>>- Country</option>
			<option value="landmark" <?php echo (get_option('open_graph_type')=='landmark')?'selected':''; ?>>- Landmark</option>
			<option value="state_province" <?php echo (get_option('open_graph_type')=='state_province')?'selected':''; ?>>- State Province</option>
			<option disabled="true">PRODUCTS AND ENTERTAINMENT</option>
			<option value="album" <?php echo (get_option('open_graph_type')=='album')?'selected':''; ?>>- Album</option>
			<option value="book" <?php echo (get_option('open_graph_type')=='book')?'selected':''; ?>>- Book</option>
			<option value="drink" <?php echo (get_option('open_graph_type')=='drink')?'selected':''; ?>>- Drink</option>
			<option value="food" <?php echo (get_option('open_graph_type')=='food')?'selected':''; ?>>- Food</option>
			<option value="game" <?php echo (get_option('open_graph_type')=='game')?'selected':''; ?>>- Game</option>
			<option value="product" <?php echo (get_option('open_graph_type')=='product')?'selected':''; ?>>- Product</option>
			<option value="song" <?php echo (get_option('open_graph_type')=='song')?'selected':''; ?>>- Song</option>
			<option value="movie" <?php echo (get_option('open_graph_type')=='movie')?'selected':''; ?>>- Movie</option>
			<option value="tv_show" <?php echo (get_option('open_graph_type')=='tv_show')?'selected':''; ?>>- TV Show</option>
			<option disabled="true">WEBSITES</option>
			<option value="blog" <?php echo (get_option('open_graph_type')=='blog')?'selected':''; ?>>- Blog</option>
			<option value="website" <?php echo (get_option('open_graph_type')=='website')?'selected':''; ?>>- Website</option>
			<option value="article" <?php echo (get_option('open_graph_type')=='article')?'selected':''; ?>>- Article</option>
		</select><span class="description"> The type of your site. <a href="http://developers.facebook.com/docs/opengraph#types">More info</a>.</span></td>
        </tr>
        
        <tr valign="top">
        <th scope="row">Image: *</th>
        <td><input type="text" name="open_graph_image" value="<?php echo get_option('open_graph_image'); ?>" /><span class="description"> An image URL which should represent your object within the graph. The image must be at least 50px by 50px and have a maximum aspect ratio of 3:1. Supported formats are PNG, JPEG and GIF. Use absolute path.</span></td>
        </tr>
		
		<tr valign="top">
        <th scope="row">URL: *</th>
        <td><input type="text" name="open_graph_url" value="<?php echo get_option('open_graph_url'); ?>" /><span class="description"> The canonical URL of your object that will be used as its permanent ID in the graph.</span></td>
        </tr>
		
		<tr valign="top">
        <th scope="row">Site Name: </th>
        <td><input type="text" name="open_graph_site_name" value="<?php echo get_option('open_graph_site_name'); ?>" /><span class="description"> A human-readable name for your site.</span></td>
        </tr>
		
		<tr valign="top">
        <th scope="row">Admins: </th>
        <td><input type="text" name="open_graph_admins" value="<?php echo get_option('open_graph_admins'); ?>" /><span class="description"> A comma-separated list of either Facebook user IDs or a Facebook Platform application ID that administers this page.</span></td>
        </tr>
		
		<tr valign="top">
        <th scope="row">Description: </th>
        <td><input type="text" name="open_graph_description" value="<?php echo get_option('open_graph_description'); ?>" /><span class="description"> A one to two sentence description of your page.</span></td>
        </tr>
    </table>
	
	<p>
	<br/>*<span class="description"> required field.</span>
    </p>
	
	<p>
	<br/><span class="description">When you are done and have saved you may test that you have entered everything correctly <a href="http://developers.facebook.com/tools/lint?url=<?php get_option('open_graph_url');?>">here</a>.</span>
    </p>
	
    <p class="submit">
    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
    </p>

</form>
</div>
<?php } ?>